Stan Math Library: stan/math/prim/scal/meta/child_type.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

child_type.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_CHILD_TYPE_HPP
2 #define STAN_MATH_PRIM_SCAL_META_CHILD_TYPE_HPP
3
4 namespace stan {
5
6 namespace math {
7
18 template <typename T>
19 struct child_type {
20 typedef double type;
21 };
22
33 template <template<typename> class T_struct, typename T_child>
34 struct child_type<T_struct<T_child> >{
35 typedef T_child type;
36 };
37
38 }
39 }
40
41
42 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::child_type< T_struct< T_child > >::type
T_child type
Definition: child_type.hpp:35
stan::math::child_type::type
double type
Definition: child_type.hpp:20
stan::math::child_type
Primary template class for metaprogram to compute child type of T.
Definition: child_type.hpp:19

[ Stan Home Page ] © 2011–2016, Stan Development Team.